@@ -36,11 +36,14 @@ from qiskit.circuit import (
     Barrier,
     Instruction,
     Gate,
+    ControlledGate,
     Measure,
     Parameter,
     ParameterExpression,
     Reset,
 )
+from qiskit.circuit.library import CRYGate, RYGate, MCMT  # type: ignore
+
 from qiskit.extensions.unitary import UnitaryGate  # type: ignore
 from qiskit.providers import BaseBackend  # type: ignore
 from pytket.circuit import (  # type: ignore
@@ -113,13 +116,14 @@ _qiskit_gates_other = {
     qiskit_gates.C3XGate: OpType.CnX,
     qiskit_gates.C4XGate: OpType.CnX,
     qiskit_gates.CCXGate: OpType.CCX,
-    qiskit_gates.CRYGate: OpType.CnRy,
     qiskit_gates.CSwapGate: OpType.CSWAP,
     # Multi-controlled gates (qiskit expects a list of controls followed by the target):
     qiskit_gates.MCXGate: OpType.CnX,
     qiskit_gates.MCXGrayCode: OpType.CnX,
     qiskit_gates.MCXRecursive: OpType.CnX,
     qiskit_gates.MCXVChain: OpType.CnX,
+    # Note: should be OpType.CRy, but not currently available
+    qiskit_gates.CRYGate: OpType.CnRy,
     # Special types:
     Barrier: OpType.Barrier,
     Instruction: OpType.CircBox,
@@ -135,6 +139,11 @@ _known_qiskit_gate = {**_qiskit_gates_1q, **_qiskit_gates_2q, **_qiskit_gates_ot
 # In such cases this reversal will select one or the other.
 _known_qiskit_gate_rev = {v: k for k, v in _known_qiskit_gate.items()}
 
+# One way mapping: CRY is a special case of CnRy, but not vice versa.
+# Constructing a qiskit CnRy gate is not just a single step,
+# so treat as a special case.
+del _known_qiskit_gate_rev[OpType.CnRy]
+
 # Ensure U3 maps to U3Gate. (UGate not yet fully supported in Qiskit.)
 _known_qiskit_gate_rev[OpType.U3] = qiskit_gates.U3Gate
 
@@ -215,9 +224,22 @@ class CircuitBuilder:
                     "condition_bits": [cond_reg[k] for k in range(len(cond_reg))],
                     "condition_value": i.condition[1],
                 }
-            optype = _known_qiskit_gate[type(i)]
+            if type(i) == ControlledGate:
+                if type(i.base_gate) == qiskit_gates.RYGate:
+                    optype = OpType.CnRy
+                else:
+                    # Maybe handle multicontrolled gates in a more general way,
+                    # but for now just do CnRy
+                    raise NotImplementedError(
+                        "qiskit ControlledGate with "
+                        + "base gate {} not implemented".format(i.base_gate)
+                    )
+            else:
+                optype = _known_qiskit_gate[type(i)]
+
             qubits = [self.qregmap[qbit.register][qbit.index] for qbit in qargs]
             bits = [self.cregmap[bit.register][bit.index] for bit in cargs]
+
             if optype == OpType.Unitary2qBox:
                 u = i.to_matrix()
                 ubox = Unitary2qBox(u)
@@ -370,6 +392,24 @@ def append_tk_command_to_qiskit(
     qargs = [qregmap[q.reg_name][q.index[0]] for q in args]
     if optype == OpType.CnX:
         return qcirc.mcx(qargs[:-1], qargs[-1])
+
+    # special case
+    if optype == OpType.CnRy:
+        # might as well do a bit more checking
+        assert len(op.params) == 1
+        alpha = param_to_qiskit(op.params[0], symb_map)
+        assert len(qargs) >= 2
+        if len(qargs) == 2:
+            # presumably more efficient; single control only
+            new_gate = CRYGate(alpha)
+        else:
+            new_ry_gate = RYGate(alpha)
+            new_gate = MCMT(
+                gate=new_ry_gate, num_ctrl_qubits=len(qargs) - 1, num_target_qubits=1
+            )
+        qcirc.append(new_gate, qargs)
+        return qcirc
+
     # others are direct translations
     try:
         gatetype = _known_qiskit_gate_rev[optype]
